@@ -323,7 +323,7 @@ static const LossyFile gdcmLossyFilenames[] = {
 { 0,"D_CLUNIE_VL4_RLE.dcm" },
 { 0,"D_CLUNIE_RG1_RLE.dcm" },
 { 1,"JDDICOM_Sample2.dcm" },
-{0,"AMIInvalidPrivateDefinedLengthSQasUN.dcm" },
+{ 0,"AMIInvalidPrivateDefinedLengthSQasUN.dcm" },
 { 0,"SIEMENS_MAGNETOM-12-MONO2-FileSeq3.dcm" },
 { 0,"CT-MONO2-8-abdo.dcm" },
 { 0,"D_CLUNIE_SC1_RLE.dcm" },
@@ -416,24 +416,31 @@ static const LossyFile gdcmLossyFilenames[] = {
 { 1,"multiframegrayscalewordscis.dcm" },
 { 1,"multiframesinglebitscis.dcm" },
 { 1,"multiframetruecolorscis.dcm" },
-{ 1, "SinglePrecisionSC.dcm" },
-{ 0, "signedtruecoloroldsc.dcm" },
-{ 0, "o.dcm" },
-{ 0, "UnexpectedSequenceDelimiterInFixedLengthSequence.dcm" },
-{ 0, "IM-0001-0066.CommandTag00.dcm" },
-{ 0, "NM_Kakadu44_SOTmarkerincons.dcm" },
-{ 0, "GDCMJ2K_TextGBR.dcm" },
-{ 0, "PhilipsInteraSeqTermInvLen.dcm" },
-{ 0, "LIBIDO-24-ACR_NEMA-Rectangle.dcm" },
-{ 0, "TOSHIBA_J2K_SIZ1_PixRep0.dcm" },
-{ 0, "TOSHIBA_J2K_SIZ0_PixRep1.dcm" },
-{ 0, "TOSHIBA_J2K_OpenJPEGv2Regression.dcm" },
-{ 0, "NM-PAL-16-PixRep1.dcm" },
-{ 0, "MEDILABInvalidCP246_EVRLESQasUN.dcm" },
-{ 0, "JPEGInvalidSecondFrag.dcm" },
-{ 0, "SC16BitsAllocated_8BitsStoredJ2K.dcm" },
-{ 0, "SC16BitsAllocated_8BitsStoredJPEG.dcm" },
-{ 0, "SIEMENS_SYNGO-12-MONO2-LUTWrongLength512.dcm" },
+{ 1,"SinglePrecisionSC.dcm" },
+{ 0,"signedtruecoloroldsc.dcm" },
+{ 0,"o.dcm" },
+{ 0,"UnexpectedSequenceDelimiterInFixedLengthSequence.dcm" },
+{ 0,"IM-0001-0066.CommandTag00.dcm" },
+{ 0,"NM_Kakadu44_SOTmarkerincons.dcm" },
+{ 0,"GDCMJ2K_TextGBR.dcm" },
+{ 0,"PhilipsInteraSeqTermInvLen.dcm" },
+{ 0,"LIBIDO-24-ACR_NEMA-Rectangle.dcm" },
+{ 0,"TOSHIBA_J2K_SIZ1_PixRep0.dcm" },
+{ 0,"TOSHIBA_J2K_SIZ0_PixRep1.dcm" },
+{ 0,"TOSHIBA_J2K_OpenJPEGv2Regression.dcm" },
+{ 0,"NM-PAL-16-PixRep1.dcm" },
+{ 0,"MEDILABInvalidCP246_EVRLESQasUN.dcm" },
+{ 0,"JPEGInvalidSecondFrag.dcm" },
+{ 0,"SC16BitsAllocated_8BitsStoredJ2K.dcm" },
+{ 0,"SC16BitsAllocated_8BitsStoredJPEG.dcm" },
+{ 0,"SIEMENS_SYNGO-12-MONO2-LUTWrongLength512.dcm" },
+{ 0,"JPEGLS_CharLS_10742.dcm" },
+{ 1,"JPEGLosslessYBR_FULL_422.dcm" },
+{ 1,"JPEGNote_empty.dcm" },
+{ 1,"JPEGNote_missing.dcm" },
+{ 1,"JPEGNote_bogus.dcm" },
+{ 0,"RLEDebianBug816607Orig.dcm" },
+{ 0,"IllegalGroup2ImplicitTS.dcm" },
 { 0, NULL }
 };
 
