@@ -526,6 +526,7 @@ std::istream &FileMetaInformation::Read(std::istream &is)
   //ExplicitAttribute<0x0002,0x0000> metagl;
   //metagl.Read(is);
 
+  std::streampos start = is.tellg();
   // TODO: Can now load data from std::ios::cur to std::ios::cur + metagl.GetValue()
 
   ExplicitDataElement xde;
@@ -545,10 +546,36 @@ std::istream &FileMetaInformation::Read(std::istream &is)
 //#endif
   Insert( xde );
   // See PS 3.5, Data Element Structure With Explicit VR
+  try {
+  // GDCM is a hack, so let's read all possible group 2 element, until the last one
+  // and leave the group length value aside.
   while( ReadExplicitDataElement<SwapperNoOp>(is, xde ) )
     {
     Insert( xde );
     }
+  }
+  catch( std::exception & ex )
+  {
+(void)ex;
+    // we've read a little bit too much. We are possibly in the case where an
+    // implicit dataelement with group 2 (technically impossible) was found
+    // (first dataelement). Let's start over again, but this time use group
+    // length as the sentinel for the last group 2 element:
+  is.seekg(start,std::ios::beg);
+  // Group Length:
+  ReadExplicitDataElement<SwapperNoOp>(is, xde );
+
+  Attribute<0x0002, 0x0000> filemetagrouplength;
+  filemetagrouplength.SetFromDataElement( xde );
+  const unsigned int glen = filemetagrouplength.GetValue();
+
+  unsigned int cur_len = 0;
+    while( cur_len < glen && ReadExplicitDataElement<SwapperNoOp>(is, xde ) )
+   {
+    Insert( xde );
+    cur_len += xde.GetLength();
+    }
+  }
 
   // Now is a good time to compute the transfer syntax:
   ComputeDataSetTransferSyntax();
@@ -751,7 +778,34 @@ std::istream &FileMetaInformation::ReadCompatInternal(std::istream &is)
           }
         }
       // Now is a good time to find out the dataset transfer syntax
+      try {
       ComputeDataSetTransferSyntax();
+      } catch( gdcm::Exception & ex ) {
+        // We were able to read some of the Meta Header, but failed to compute the DataSetTS
+        // technically GDCM is able to cope with any value here. But be kind and try to have a good guess:
+     
+          gdcmWarningMacro( "Meta Header is bogus. Guessing DataSet TS." );
+  Tag t;
+  if( !t.Read<SwapperNoOp>(is) )
+    {
+    throw Exception( "Cannot read very first tag" );
+    }
+
+    char vr_str[3];
+    is.read(vr_str, 2);
+    vr_str[2] = '\0';
+    VR::VRType vr = VR::GetVRType(vr_str);
+    if( vr != VR::VR_END )
+      {
+      DataSetTS = TransferSyntax::ExplicitVRLittleEndian;
+      }
+    else
+      {
+      DataSetTS = TransferSyntax::ImplicitVRLittleEndian;
+      }
+    is.seekg(-6, std::ios::cur); // Seek back
+
+      }
       }
     }
 //  else
