@@ -39,7 +39,7 @@
 #include "vtkImageMapToWindowLevelColors.h"
 #include "vtkImageActor.h"
 #include "vtkWindowToImageFilter.h"
-#if VTK_MAJOR_VERSION >= 5 && VTK_MINOR_VERSION > 0
+#if VTK_MAJOR_VERSION >= 6 || (VTK_MAJOR_VERSION >= 5 && VTK_MINOR_VERSION > 0)
 #include "vtkImageMapToColors16.h"
 #include "vtkBalloonWidget.h"
 #include "vtkBalloonRepresentation.h"
@@ -88,6 +88,13 @@ class vtkAngleWidget;
 
 #include <getopt.h>
 #include <assert.h>
+
+#if VTK_MAJOR_VERSION >= 6
+#ifndef vtkFloatingPointType
+#define vtkFloatingPointType double
+#endif
+#endif
+
 //----------------------------------------------------------------------------
 // vtkImageViewer2 new interface wants SetSlice, but vtkImageViewer does not have
 // this new interface (what a pain), so let's fake a new interface to
@@ -95,7 +102,11 @@ class vtkAngleWidget;
 class vtkGDCMImageViewer : public vtkImageViewer
 {
 public:
+#if VTK_MAJOR_VERSION < 6
   vtkTypeRevisionMacro(vtkGDCMImageViewer,vtkImageViewer);
+#else
+  vtkTypeMacro(vtkGDCMImageViewer,vtkImageViewer);
+#endif
 
   static vtkGDCMImageViewer *New()
     {
@@ -118,7 +129,11 @@ public:
   double GetOverlayVisibility() { return 0; }
   void SetOverlayVisibility(double vis) {(void)vis;}
 };
+#if VTK_MAJOR_VERSION < 6
 vtkCxxRevisionMacro(vtkGDCMImageViewer, "$Revision: 1.30 $")
+#else
+//vtkCxxRevisionMacro(vtkGDCMImageViewer, "$Revision: 1.30 $")
+#endif
 vtkInstantiatorNewMacro(vtkGDCMImageViewer)
 
 #if VTK_MAJOR_VERSION >= 5
@@ -126,7 +141,11 @@ vtkInstantiatorNewMacro(vtkGDCMImageViewer)
 class vtkImageColorViewer : public vtkImageViewer2
 {
 public:
+#if VTK_MAJOR_VERSION < 6
   vtkTypeRevisionMacro(vtkImageColorViewer,vtkImageViewer2);
+#else
+  vtkTypeMacro(vtkImageColorViewer,vtkImageViewer2);
+#endif
 
   static vtkImageColorViewer *New()
     {
@@ -164,7 +183,11 @@ public:
 private:
   vtkImageActor                   *OverlayImageActor;
 };
+#if VTK_MAJOR_VERSION < 6
 vtkCxxRevisionMacro(vtkImageColorViewer, "$Revision: 1.30 $")
+#else
+//vtkCxxRevisionMacro(vtkImageColorViewer, "$Revision: 1.30 $")
+#endif
 vtkInstantiatorNewMacro(vtkImageColorViewer)
 #endif
 
@@ -213,7 +236,7 @@ public:
           vtkPNGWriter * writer = vtkPNGWriter::New();
           vtkWindowToImageFilter * w2i = vtkWindowToImageFilter::New();
           w2i->SetInput( rwi->GetRenderWindow() );
-#if (VTK_MAJOR_VERSION >= 6)
+#if VTK_MAJOR_VERSION >= 6
           writer->SetInputConnection( w2i->GetOutputPort() );
 #else
           writer->SetInput( w2i->GetOutput() );
@@ -224,7 +247,7 @@ public:
           w2i->Delete();
           //std::cerr << "Screenshort saved to snapshot.png" << std::endl;
           }
-#if VTK_MAJOR_VERSION >= 5 && VTK_MINOR_VERSION > 0
+#if VTK_MAJOR_VERSION >= 6 || (VTK_MAJOR_VERSION >= 5 && VTK_MINOR_VERSION > 0)
         else if ( keycode == 'l' )
           {
           IconWidget->Off();
@@ -251,7 +274,7 @@ public:
 #endif
         else
           {
-#if (VTK_MAJOR_VERSION >= 5) || ( VTK_MAJOR_VERSION == 4 && VTK_MINOR_VERSION > 5 )
+#if VTK_MAJOR_VERSION >= 5 || (VTK_MAJOR_VERSION == 4 && VTK_MINOR_VERSION > 5)
           int max = ImageViewer->GetSliceMax();
           int slice = (ImageViewer->GetSlice() + 1) % ++max;
           ImageViewer->SetSlice( slice );
@@ -292,7 +315,7 @@ public:
 
 int verbose;
 
-#if VTK_MAJOR_VERSION >= 5 && VTK_MINOR_VERSION > 0
+#if VTK_MAJOR_VERSION >= 6 || (VTK_MAJOR_VERSION >= 5 && VTK_MINOR_VERSION > 0)
 class vtkBalloonCallback : public vtkCommand
 {
 public:
@@ -390,7 +413,7 @@ void ExecuteViewer(TViewer *viewer, vtkStringArray *filenames)
     viewer->AddInputConnection ( reader->GetOverlayPort(0) );
     }
   // TODO: Icon can be added using the vtkLogoWidget
-#if VTK_MAJOR_VERSION >= 5 && VTK_MINOR_VERSION > 0
+#if VTK_MAJOR_VERSION >= 6 || (VTK_MAJOR_VERSION >= 5 && VTK_MINOR_VERSION > 0)
   vtkPointHandleRepresentation2D *handle = vtkPointHandleRepresentation2D::New();
   handle->GetProperty()->SetColor(1,0,0);
   vtkDistanceRepresentation2D *drep = vtkDistanceRepresentation2D::New();
@@ -514,7 +537,7 @@ void ExecuteViewer(TViewer *viewer, vtkStringArray *filenames)
   // MONOCHROME1 is also implemented with a lookup table
   if( reader->GetImageFormat() == VTK_LOOKUP_TABLE || reader->GetImageFormat() == VTK_INVERSE_LUMINANCE )
     {
-#if VTK_MAJOR_VERSION >= 5 && VTK_MINOR_VERSION > 0
+#if VTK_MAJOR_VERSION >= 6 || (VTK_MAJOR_VERSION >= 5 && VTK_MINOR_VERSION > 0)
     assert( reader->GetOutput()->GetPointData()->GetScalars()
       && reader->GetOutput()->GetPointData()->GetScalars()->GetLookupTable() );
 #endif
@@ -525,11 +548,11 @@ void ExecuteViewer(TViewer *viewer, vtkStringArray *filenames)
       // This must be a Segmented Palette and on VTK 4.4 this is not supported
       std::cerr << "Not implemented. You will not see the Color LUT" << std::endl;
       }
-#if VTK_MAJOR_VERSION >= 5 && VTK_MINOR_VERSION > 0
+#if VTK_MAJOR_VERSION >= 6 || (VTK_MAJOR_VERSION >= 5 && VTK_MINOR_VERSION > 0)
     if( lut->IsA( "vtkLookupTable16" ) )
       {
       vtkImageMapToColors16 *map = vtkImageMapToColors16::New ();
-#if (VTK_MAJOR_VERSION >= 6)
+#if VTK_MAJOR_VERSION >= 6
       map->SetInputConnection (reader->GetOutputPort());
 #else
       map->SetInput (reader->GetOutput());
@@ -545,7 +568,7 @@ void ExecuteViewer(TViewer *viewer, vtkStringArray *filenames)
         }
       map->Update();
       map->GetOutput()->GetScalarRange(range);
-#if (VTK_MAJOR_VERSION >= 6)
+#if VTK_MAJOR_VERSION >= 6
       viewer->SetInputConnection( map->GetOutputPort() );
 #else
       viewer->SetInput( map->GetOutput() );
@@ -556,7 +579,7 @@ void ExecuteViewer(TViewer *viewer, vtkStringArray *filenames)
 #endif
       {
       vtkImageMapToColors *map = vtkImageMapToColors::New ();
-#if (VTK_MAJOR_VERSION >= 6)
+#if VTK_MAJOR_VERSION >= 6
       map->SetInputConnection (reader->GetOutputPort());
 #else
       map->SetInput (reader->GetOutput());
@@ -572,7 +595,7 @@ void ExecuteViewer(TViewer *viewer, vtkStringArray *filenames)
         }
       map->Update();
       map->GetOutput()->GetScalarRange(range);
-#if (VTK_MAJOR_VERSION >= 6)
+#if VTK_MAJOR_VERSION >= 6
       viewer->SetInputConnection( map->GetOutputPort() );
 #else
       viewer->SetInput( map->GetOutput() );
@@ -584,14 +607,14 @@ void ExecuteViewer(TViewer *viewer, vtkStringArray *filenames)
     {
 #if VTK_MAJOR_VERSION >= 5
     vtkImageYBRToRGB *filter = vtkImageYBRToRGB::New();
-#if (VTK_MAJOR_VERSION >= 6)
+#if VTK_MAJOR_VERSION >= 6
     filter->SetInputConnection( reader->GetOutputPort() );
 #else
     filter->SetInput( reader->GetOutput() );
 #endif
     filter->Update();
     filter->GetOutput()->GetScalarRange(range);
-#if (VTK_MAJOR_VERSION >= 6)
+#if VTK_MAJOR_VERSION >= 6
     viewer->SetInputConnection( filter->GetOutputPort() );
 #else
     viewer->SetInput( filter->GetOutput() );
@@ -618,7 +641,7 @@ void ExecuteViewer(TViewer *viewer, vtkStringArray *filenames)
   if( reader->GetCurve() )
     {
     vtkPolyDataMapper2D * rectMapper = vtkPolyDataMapper2D::New();
-#if (VTK_MAJOR_VERSION >= 6)
+#if VTK_MAJOR_VERSION >= 6
     rectMapper->SetInputData( reader->GetCurve() );
 #else
     rectMapper->SetInput( reader->GetCurve() );
@@ -699,7 +722,7 @@ void ExecuteViewer(TViewer *viewer, vtkStringArray *filenames)
   // Here is where we setup the observer,
   vtkGDCMObserver<TViewer> *obs = vtkGDCMObserver<TViewer>::New();
   obs->ImageViewer = viewer;
-#if VTK_MAJOR_VERSION >= 5 && VTK_MINOR_VERSION > 0
+#if VTK_MAJOR_VERSION >= 6 || (VTK_MAJOR_VERSION >= 5 && VTK_MINOR_VERSION > 0)
   if(iconwidget) iconwidget->On();
   obs->IconWidget = iconwidget;
   obs->DistanceWidget = dwidget;
@@ -742,7 +765,7 @@ void ExecuteViewer(TViewer *viewer, vtkStringArray *filenames)
 #endif
 
   reader->Delete();
-#if VTK_MAJOR_VERSION >= 5 && VTK_MINOR_VERSION > 0
+#if VTK_MAJOR_VERSION >= 6 || (VTK_MAJOR_VERSION >= 5 && VTK_MINOR_VERSION > 0)
   cbk->Delete();
   dwidget->Off();
   balloonwidget->Off();
